HIL-MCP 统一管理台

⚡

# JARVIS

HIL-MCP 统一管理台

用户名
密码
🎯
HIL Server
v2.0.0
运行中
-
活跃会话
-
总会话数
-
端口
-
模式
🔌
DevCloud Worker
Relay 代理
未连接
-
连接数
-
活跃
连接的 Worker:
🔀
Forward Service
v1.1.0
未配置
-
总请求
-
成功
-
转发规则
-
超时(s)
数据详情
HIL 会话
Forward 日志
转发规则
空闲提示配置
Short ID
Chat ID
消息内容
项目
状态
创建时间
加载中...
时间
用户
Chat ID
内容
状态
耗时
加载中...
管理 Forward Service 的转发规则
Chat ID
URL 模板
Agent ID
API Key
操作
加载中...
配置当用户发送消息但机器人未在等待回复时的自动回复消息（支持热更新）

### 全局默认配置

启用
消息模板（支持变量：{user_name}, {chat_id}, {chat_type}, {timestamp}） 👋 你好 {user_name}！ 当前没有等待中的会话需要你回复。 如果你想配置 MCP 使用此{chat_type}，请使用以下信息： 📋 **Chat ID**: `{chat_id}` 📌 **会话类型**: {chat_type} 🕐 **时间**: {timestamp} 你可以将此 Chat ID 配置到 MCP 的环境变量中： ``` DEFAULT_CHAT_ID={chat_id} ```
💡 提示：配置保存后立即生效，无需重启服务

### Chat ID 特定配置

为特定的 Chat ID 配置自定义消息，优先级高于全局默认配置
Chat ID
消息模板
状态
操作
加载中...
添加转发规则
Chat ID *
URL 模板 *
Agent ID
API Key
名称（可选）
编辑 Worker 配置
Worker ID
BOT_KEY *
HIL_URL
回调端口
⚠️ 修改配置后需要重启服务才能生效
添加 Chat ID 配置
Chat ID *
消息模板 *
启用此配置
💡 此配置会覆盖全局默认配置，仅对指定的 Chat ID 生效